{% extends "ralph_pricing/report.html" %}
{% load url from future %}
{% load i18n %}

{% block description %}
{% trans "This report provides detailed info regarding costs for all ventures within selected time frame." %}
{% endblock %}
