hosts_usages_data = [
    {
        u'MBytes': u'10318.234132',
        u'sourcetype': u'splunk_host1',
        u'percent': u'27.40',
        u'source': u'/var/log/apache2/error.log',
        u'host': u'test_host1',
        u'lastReceived': u'Thu 2013-05-16 06:09:09',
    },
    {
        u'MBytes': u'1326.640829',
        u'sourcetype': u'splunk_host2',
        u'percent': u'3.52',
        u'source': u'WinEventLog',
        u'host': u'test_host2',
        u'lastReceived': u'Fri 2013-05-17 07:26:16',
    },
    {
        u'MBytes': u'1048.363416',
        u'sourcetype': u'syslog',
        u'percent': u'2.78',
        u'source': u'syslog',
        u'host': u'test_host3',
        u'lastReceived': u'Fri 2013-05-17 07:27:02',
    },
]

